@@ -1,24 +1,20 @@
-count.overplot<-function(x,y,tol=NULL,...) {
- if(missing(x))
-  stop("Usage: count.overplot(x,y,tol=NULL,...)")
+count.overplot<-function(x,y,tol=NULL,col=par("fg"),pch=1,...) {
+ if(missing(x)) stop("Usage: count.overplot(x,y,tol=NULL,...)")
  dimx<-dim(x)
  if(missing(y)) {
   if(is.list(x) && names(x)[1] == "x") {
-   # looks like xy.coords
    y<-x[[2]]
    x<-x[[1]]
   }
   else {
-   # if x is a data frame or matrix with at least two columns, split it
    if(!is.null(dimx)) {
     y<-x[,2]
     x<-x[,1]
    }
   }
  }
- # get rid of any pairs containing NA
- if(any(is.na(x)|is.na(y))) {
-  indices<-!is.na(x)&!is.na(y)
+ if(any(is.na(x) | is.na(y))) {
+  indices<-!is.na(x) & !is.na(y)
   x<-x[indices]
   y<-y[indices]
  }
@@ -26,29 +22,39 @@ count.overplot<-function(x,y,tol=NULL,...) {
  ylim<-range(y)
  xlen<-length(x)
  if(xlen != length(y)) stop("x and y must be the same length.")
- if(is.null(tol)) tol<-c(strwidth("o")/2,strheight("o")/2)
- else if(length(tol)==1) tol<-rep(tol,2)
+ if(is.null(tol)) {
+  plot(x,y,type="n",axes=FALSE,xlab="",ylab="")
+  tol<-c(strwidth("o")/2,strheight("o")/2)
+ }
+ else {
+  if (length(tol) == 1) tol <- rep(tol,2)
+ }
+ if(length(col) < xlen) col<-rep(col,xlen)
+ if(length(pch) < xlen) pch<-rep(pch,xlen)
  flags<-1:xlen
- xsep<-ysep<-xdup<-ydup<-xydup<-rep(0,xlen)
+ xsep<-ysep<-xdup<-ydup<-xydup<-sepcol<-seppch<-rep(0,xlen)
  nsep<-ndup<-0
  for(i in 1:xlen) {
   if(!is.na(flags[i])) {
    dups<-abs(x - x[i]) <= tol[1] & abs(y - y[i]) <= tol[2]
    ndups<-sum(dups)
    if(ndups > 1) {
-    ndup<-ndup+1
+    ndup<-ndup + 1
     xydup[ndup]<-ndups
     xdup[ndup]<-x[i]
     ydup[ndup]<-y[i]
    }
    else {
-    nsep<-nsep+1
+    nsep<-nsep + 1
     xsep[nsep]<-x[i]
     ysep[nsep]<-y[i]
+    sepcol[nsep]<-col[i]
+    seppch[nsep]<-pch[i]
    }
   }
   flags[dups]<-NA
  }
- plot(xsep[1:nsep],ysep[1:nsep],xlim=xlim,ylim=ylim,...)
+ plot(xsep[1:nsep],ysep[1:nsep],xlim=xlim,ylim=ylim,
+  col=sepcol[1:nsep],pch=seppch[1:nsep],...)
  text(xdup[1:ndup],ydup[1:ndup],xydup[1:ndup])
 }
